@@ -3,11 +3,11 @@
 #' Function to construct a confidence interval around an effect size or mean effect size.
 #'
 #' @param mean Mean effect size (if used in a meta-analysis) or observed effect size (if used on individual statistics).
-#' @param se For individual statistic.: standard error of the statistic.
-#' @param sd For meta-analyses: Observed standard deviation of effect sizes, before accouting for variance from artifacts.
-#' @param k For meta-analyses: Number of studies in the meta-analysis.
+#' @param se Standard error of the statistic.
+#' @param df Degrees of freedom of the statistic (necessary if using the \emph{t} distribution).
 #' @param conf_level Confidence level that defines the width of the confidence interval (default = .95).
 #' @param conf_method Distribution to be used to compute the width of confidence intervals. Available options are "t" for \emph{t} distribution or "norm" for normal distribution.
+#' @param ... Additional arguments
 #'
 #' @return A matrix of confidence intervals of the specified width.
 #' @export
@@ -16,24 +16,48 @@
 #' \deqn{CI=mean_{es}\pm quantile\times SE_{es}}{CI = mean_es +/- quantile * SE_es}
 #'
 #' @examples
-#' confidence(mean = .3, sd = .15, k = 10, conf_level = .95)
-#' confidence(mean = c(.3, .5), sd = c(.15, .2), k = c(10, 5), conf_level = .95)
-#' confidence(mean = c(.3, .5), se = c(.15, .2), conf_level = .95)
-confidence <- function(mean, se = NULL, sd = NULL, k = 1, conf_level = .95, conf_method = "t"){
+#' confidence(mean = c(.3, .5), se = c(.15, .2), df = c(100, 200), conf_level = .95, conf_method = "t")
+#' confidence(mean = c(.3, .5), se = c(.15, .2), conf_level = .95, conf_method = "norm")
+confidence <- function(mean, se = NULL, df = NULL, conf_level = .95, conf_method = "t", ...){
      conf_level <- interval_warning(interval = conf_level, interval_name = "conf_level", default = .95)
      conf_method <- scalar_arg_warning(arg = conf_method, arg_name = "conf_method")
      conf_method <- match.arg(arg = conf_method, c("t", "norm"))
 
+     sd <- list(...)$sd
+     k <- list(...)$k
+     if(is.null(df) & !is.null(k)){
+          df <- k
+          df[k > 1] <- k[k > 1] - 1
+     }
+
      if(is.null(se)){
-          if(!is.null(sd)){
+          if(!is.null(sd) & !is.null(k)){
                sd[is.na(sd)] <- 0
                se <- sd / sqrt(k)
           }else{
-               warning("Either 'se' or 'sd' and 'k' must be supplied")
+               warning("'se' must be supplied")
           }
      }
-     conf_interval_ll <- mean - qnorm((1 - conf_level) / 2, lower.tail = FALSE) * se
-     conf_interval_ul <- mean + qnorm((1 - conf_level) / 2, lower.tail = FALSE) * se
+
+     if(conf_method == "t"){
+          if(!is.null(df)){
+               valid_df <- df > 0
+               if(any(!valid_df))
+                    warning("Some df values were not valid: The normal distribution was used for these cases instead of the t distribution", call. = FALSE)
+               conf_quantile <- rep(qnorm((1 - conf_level) / 2, lower.tail = FALSE), length(df))
+               # conf_quantile <- rep(NA, length(df))
+               conf_quantile[valid_df] <- qt(p = (1 - conf_level) / 2, df = df[valid_df], lower.tail = FALSE)
+          }else{
+               warning("df is NULL: The normal distribution was used to define confidence intervals instead of the t distribution", call. = FALSE)
+               conf_quantile <- qnorm((1 - conf_level) / 2, lower.tail = FALSE)
+          }
+     }
+     if(conf_method == "norm"){
+          conf_quantile <- qnorm((1 - conf_level) / 2, lower.tail = FALSE)
+     }
+
+     conf_interval_ll <- mean - conf_quantile * se
+     conf_interval_ul <- mean + conf_quantile * se
 
      conf_interval <- cbind(conf_interval_ll, conf_interval_ul)
      colnames(conf_interval) <- paste("CI", c("LL", "UL"), round(conf_level * 100), sep = "_")
@@ -46,7 +70,7 @@ confidence <- function(mean, se = NULL, sd = NULL, k = 1, conf_level = .95, conf
 #' Function to construct a credibility interval around a mean effect size.
 #'
 #' @param mean Mean effect size.
-#' @param sd Residual/true standard deviation of effect sizes, after accouting for variance from artifacts.
+#' @param sd Residual/true standard deviation of effect sizes, after accounting for variance from artifacts.
 #' @param k Number of studies in the meta-analysis.
 #' @param cred_level Credibility level that defines the width of the credibility interval (default = .80).
 #' @param cred_method Distribution to be used to compute the width of credibility intervals. Available options are "t" for \emph{t} distribution or "norm" for normal distribution.
@@ -68,10 +92,11 @@ credibility <- function(mean, sd, k = NULL, cred_level = .8, cred_method = "t"){
 
      if(cred_method == "t"){
           if(!is.null(k)){
+               # cred_quantile <- rep(qnorm((1 - cred_level) / 2, lower.tail = FALSE), length(k))
                cred_quantile <- rep(NA, length(k))
                cred_quantile[k > 1] <- qt(p = (1 - cred_level) / 2, df = k[k > 1] - 1, lower.tail = FALSE)
           }else{
-               warning("k is NULL: The normal distribution was used to define credibility interval instead of the t distribution", call. = FALSE)
+               warning("k is NULL: The normal distribution was used to define credibility intervals instead of the t distribution", call. = FALSE)
                cred_quantile <- qnorm((1 - cred_level) / 2, lower.tail = FALSE)
           }
      }
